var dir_23ad537c0198e21f0d4ccda129f8fea1 =
[
    [ "fieldmaster", "dir_be67fb4f416b8f5cd1a1cf48a68a95b6.html", "dir_be67fb4f416b8f5cd1a1cf48a68a95b6" ],
    [ "textfield", "dir_504c6ba70f121b79cad8dde8180f5114.html", "dir_504c6ba70f121b79cad8dde8180f5114" ],
    [ "AuthorDisplayFormat.idl", "AuthorDisplayFormat_8idl.html", "AuthorDisplayFormat_8idl" ],
    [ "AutoTextContainer.idl", "AutoTextContainer_8idl.html", "AutoTextContainer_8idl" ],
    [ "AutoTextEntry.idl", "AutoTextEntry_8idl.html", "AutoTextEntry_8idl" ],
    [ "AutoTextGroup.idl", "AutoTextGroup_8idl.html", "AutoTextGroup_8idl" ],
    [ "BaseFrame.idl", "BaseFrame_8idl.html", "BaseFrame_8idl" ],
    [ "BaseFrameProperties.idl", "BaseFrameProperties_8idl.html", "BaseFrameProperties_8idl" ],
    [ "BaseIndex.idl", "BaseIndex_8idl.html", "BaseIndex_8idl" ],
    [ "BaseIndexMark.idl", "BaseIndexMark_8idl.html", "BaseIndexMark_8idl" ],
    [ "Bibliography.idl", "text_2Bibliography_8idl.html", "text_2Bibliography_8idl" ],
    [ "BibliographyDataField.idl", "BibliographyDataField_8idl.html", "BibliographyDataField_8idl" ],
    [ "BibliographyDataType.idl", "BibliographyDataType_8idl.html", "BibliographyDataType_8idl" ],
    [ "Bookmark.idl", "Bookmark_8idl.html", "Bookmark_8idl" ],
    [ "Bookmarks.idl", "Bookmarks_8idl.html", "Bookmarks_8idl" ],
    [ "Cell.idl", "text_2Cell_8idl.html", "text_2Cell_8idl" ],
    [ "CellProperties.idl", "text_2CellProperties_8idl.html", "text_2CellProperties_8idl" ],
    [ "CellRange.idl", "text_2CellRange_8idl.html", "text_2CellRange_8idl" ],
    [ "ChainedTextFrame.idl", "ChainedTextFrame_8idl.html", "ChainedTextFrame_8idl" ],
    [ "ChapterFormat.idl", "ChapterFormat_8idl.html", "ChapterFormat_8idl" ],
    [ "ChapterNumberingRule.idl", "ChapterNumberingRule_8idl.html", "ChapterNumberingRule_8idl" ],
    [ "CharacterCompressionType.idl", "CharacterCompressionType_8idl.html", "CharacterCompressionType_8idl" ],
    [ "ColumnSeparatorStyle.idl", "ColumnSeparatorStyle_8idl.html", "ColumnSeparatorStyle_8idl" ],
    [ "ContentControl.idl", "ContentControl_8idl.html", "ContentControl_8idl" ],
    [ "ContentIndex.idl", "ContentIndex_8idl.html", "ContentIndex_8idl" ],
    [ "ContentIndexMark.idl", "ContentIndexMark_8idl.html", "ContentIndexMark_8idl" ],
    [ "ControlCharacter.idl", "ControlCharacter_8idl.html", "ControlCharacter_8idl" ],
    [ "DateDisplayFormat.idl", "DateDisplayFormat_8idl.html", "DateDisplayFormat_8idl" ],
    [ "DefaultNumberingProvider.idl", "DefaultNumberingProvider_8idl.html", "DefaultNumberingProvider_8idl" ],
    [ "Defaults.idl", "text_2Defaults_8idl.html", "text_2Defaults_8idl" ],
    [ "DependentTextField.idl", "DependentTextField_8idl.html", "DependentTextField_8idl" ],
    [ "DialogFactoryService.idl", "DialogFactoryService_8idl.html", "DialogFactoryService_8idl" ],
    [ "DocumentIndex.idl", "DocumentIndex_8idl.html", "DocumentIndex_8idl" ],
    [ "DocumentIndexes.idl", "DocumentIndexes_8idl.html", "DocumentIndexes_8idl" ],
    [ "DocumentIndexLevelFormat.idl", "DocumentIndexLevelFormat_8idl.html", "DocumentIndexLevelFormat_8idl" ],
    [ "DocumentIndexMark.idl", "DocumentIndexMark_8idl.html", "DocumentIndexMark_8idl" ],
    [ "DocumentIndexMarkAsian.idl", "DocumentIndexMarkAsian_8idl.html", "DocumentIndexMarkAsian_8idl" ],
    [ "DocumentIndexParagraphStyles.idl", "DocumentIndexParagraphStyles_8idl.html", "DocumentIndexParagraphStyles_8idl" ],
    [ "DocumentSettings.idl", "text_2DocumentSettings_8idl.html", "text_2DocumentSettings_8idl" ],
    [ "DocumentStatistic.idl", "DocumentStatistic_8idl.html", "DocumentStatistic_8idl" ],
    [ "Endnote.idl", "Endnote_8idl.html", "Endnote_8idl" ],
    [ "EndnoteSettings.idl", "EndnoteSettings_8idl.html", "EndnoteSettings_8idl" ],
    [ "FilenameDisplayFormat.idl", "FilenameDisplayFormat_8idl.html", "FilenameDisplayFormat_8idl" ],
    [ "FontEmphasis.idl", "FontEmphasis_8idl.html", "FontEmphasis_8idl" ],
    [ "FontRelief.idl", "text_2FontRelief_8idl.html", "text_2FontRelief_8idl" ],
    [ "Footnote.idl", "Footnote_8idl.html", "Footnote_8idl" ],
    [ "FootnoteNumbering.idl", "FootnoteNumbering_8idl.html", "FootnoteNumbering_8idl" ],
    [ "Footnotes.idl", "Footnotes_8idl.html", "Footnotes_8idl" ],
    [ "FootnoteSettings.idl", "FootnoteSettings_8idl.html", "FootnoteSettings_8idl" ],
    [ "GenericTextDocument.idl", "GenericTextDocument_8idl.html", "GenericTextDocument_8idl" ],
    [ "GlobalDocument.idl", "GlobalDocument_8idl.html", "GlobalDocument_8idl" ],
    [ "GlobalSettings.idl", "GlobalSettings_8idl.html", "GlobalSettings_8idl" ],
    [ "GraphicCrop.idl", "GraphicCrop_8idl.html", "GraphicCrop_8idl" ],
    [ "HoriOrientation.idl", "HoriOrientation_8idl.html", "HoriOrientation_8idl" ],
    [ "HoriOrientationFormat.idl", "HoriOrientationFormat_8idl.html", "HoriOrientationFormat_8idl" ],
    [ "HorizontalAdjust.idl", "HorizontalAdjust_8idl.html", "HorizontalAdjust_8idl" ],
    [ "IllustrationsIndex.idl", "IllustrationsIndex_8idl.html", "IllustrationsIndex_8idl" ],
    [ "InContentMetadata.idl", "InContentMetadata_8idl.html", "InContentMetadata_8idl" ],
    [ "InvalidTextContentException.idl", "InvalidTextContentException_8idl.html", "InvalidTextContentException_8idl" ],
    [ "LabelFollow.idl", "LabelFollow_8idl.html", "LabelFollow_8idl" ],
    [ "LineBreak.idl", "LineBreak_8idl.html", "LineBreak_8idl" ],
    [ "LineNumberingProperties.idl", "LineNumberingProperties_8idl.html", "LineNumberingProperties_8idl" ],
    [ "MailMerge.idl", "MailMerge_8idl.html", "MailMerge_8idl" ],
    [ "MailMergeEvent.idl", "MailMergeEvent_8idl.html", "MailMergeEvent_8idl" ],
    [ "MailMergeType.idl", "MailMergeType_8idl.html", "MailMergeType_8idl" ],
    [ "ModuleDispatcher.idl", "text_2ModuleDispatcher_8idl.html", "text_2ModuleDispatcher_8idl" ],
    [ "NotePrintMode.idl", "NotePrintMode_8idl.html", "NotePrintMode_8idl" ],
    [ "NumberingLevel.idl", "text_2NumberingLevel_8idl.html", "text_2NumberingLevel_8idl" ],
    [ "NumberingRules.idl", "NumberingRules_8idl.html", "NumberingRules_8idl" ],
    [ "NumberingStyle.idl", "NumberingStyle_8idl.html", "NumberingStyle_8idl" ],
    [ "ObjectIndex.idl", "ObjectIndex_8idl.html", "ObjectIndex_8idl" ],
    [ "PageFootnoteInfo.idl", "PageFootnoteInfo_8idl.html", "PageFootnoteInfo_8idl" ],
    [ "PageNumberType.idl", "PageNumberType_8idl.html", "PageNumberType_8idl" ],
    [ "PagePrintSettings.idl", "PagePrintSettings_8idl.html", "PagePrintSettings_8idl" ],
    [ "Paragraph.idl", "Paragraph_8idl.html", "Paragraph_8idl" ],
    [ "ParagraphEnumeration.idl", "ParagraphEnumeration_8idl.html", "ParagraphEnumeration_8idl" ],
    [ "ParagraphHyphenationKeepType.idl", "ParagraphHyphenationKeepType_8idl.html", "ParagraphHyphenationKeepType_8idl" ],
    [ "ParagraphVertAlign.idl", "ParagraphVertAlign_8idl.html", "ParagraphVertAlign_8idl" ],
    [ "PlaceholderType.idl", "PlaceholderType_8idl.html", "PlaceholderType_8idl" ],
    [ "PositionAndSpaceMode.idl", "PositionAndSpaceMode_8idl.html", "PositionAndSpaceMode_8idl" ],
    [ "PositionLayoutDir.idl", "PositionLayoutDir_8idl.html", "PositionLayoutDir_8idl" ],
    [ "PrintSettings.idl", "text_2PrintSettings_8idl.html", "text_2PrintSettings_8idl" ],
    [ "RedlinePortion.idl", "RedlinePortion_8idl.html", "RedlinePortion_8idl" ],
    [ "ReferenceFieldPart.idl", "ReferenceFieldPart_8idl.html", "ReferenceFieldPart_8idl" ],
    [ "ReferenceFieldSource.idl", "ReferenceFieldSource_8idl.html", "ReferenceFieldSource_8idl" ],
    [ "ReferenceMark.idl", "ReferenceMark_8idl.html", "ReferenceMark_8idl" ],
    [ "ReferenceMarks.idl", "ReferenceMarks_8idl.html", "ReferenceMarks_8idl" ],
    [ "RelOrientation.idl", "RelOrientation_8idl.html", "RelOrientation_8idl" ],
    [ "RubyAdjust.idl", "RubyAdjust_8idl.html", "RubyAdjust_8idl" ],
    [ "RubyPosition.idl", "RubyPosition_8idl.html", "RubyPosition_8idl" ],
    [ "ScriptHintType.idl", "ScriptHintType_8idl.html", "ScriptHintType_8idl" ],
    [ "SectionFileLink.idl", "SectionFileLink_8idl.html", "SectionFileLink_8idl" ],
    [ "SetVariableType.idl", "SetVariableType_8idl.html", "SetVariableType_8idl" ],
    [ "Shape.idl", "text_2Shape_8idl.html", "text_2Shape_8idl" ],
    [ "SizeType.idl", "SizeType_8idl.html", "SizeType_8idl" ],
    [ "TableColumns.idl", "text_2TableColumns_8idl.html", "text_2TableColumns_8idl" ],
    [ "TableColumnSeparator.idl", "TableColumnSeparator_8idl.html", "TableColumnSeparator_8idl" ],
    [ "TableIndex.idl", "TableIndex_8idl.html", "TableIndex_8idl" ],
    [ "TableRows.idl", "text_2TableRows_8idl.html", "text_2TableRows_8idl" ],
    [ "TemplateDisplayFormat.idl", "TemplateDisplayFormat_8idl.html", "TemplateDisplayFormat_8idl" ],
    [ "Text.idl", "text_2Text_8idl.html", "text_2Text_8idl" ],
    [ "TextColumn.idl", "TextColumn_8idl.html", "TextColumn_8idl" ],
    [ "TextColumns.idl", "TextColumns_8idl.html", "TextColumns_8idl" ],
    [ "TextColumnSequence.idl", "TextColumnSequence_8idl.html", "TextColumnSequence_8idl" ],
    [ "TextContent.idl", "TextContent_8idl.html", "TextContent_8idl" ],
    [ "TextContentAnchorType.idl", "TextContentAnchorType_8idl.html", "TextContentAnchorType_8idl" ],
    [ "TextContentCollection.idl", "TextContentCollection_8idl.html", "TextContentCollection_8idl" ],
    [ "TextCursor.idl", "TextCursor_8idl.html", "TextCursor_8idl" ],
    [ "TextDocument.idl", "TextDocument_8idl.html", "TextDocument_8idl" ],
    [ "TextDocumentView.idl", "TextDocumentView_8idl.html", "TextDocumentView_8idl" ],
    [ "TextEmbeddedObject.idl", "TextEmbeddedObject_8idl.html", "TextEmbeddedObject_8idl" ],
    [ "TextEmbeddedObjects.idl", "TextEmbeddedObjects_8idl.html", "TextEmbeddedObjects_8idl" ],
    [ "TextField.idl", "text_2TextField_8idl.html", "text_2TextField_8idl" ],
    [ "TextFieldEnumeration.idl", "TextFieldEnumeration_8idl.html", "TextFieldEnumeration_8idl" ],
    [ "TextFieldMaster.idl", "TextFieldMaster_8idl.html", "TextFieldMaster_8idl" ],
    [ "TextFieldMasters.idl", "TextFieldMasters_8idl.html", "TextFieldMasters_8idl" ],
    [ "TextFields.idl", "TextFields_8idl.html", "TextFields_8idl" ],
    [ "TextFrame.idl", "TextFrame_8idl.html", "TextFrame_8idl" ],
    [ "TextFrames.idl", "TextFrames_8idl.html", "TextFrames_8idl" ],
    [ "TextGraphicObject.idl", "TextGraphicObject_8idl.html", "TextGraphicObject_8idl" ],
    [ "TextGraphicObjects.idl", "TextGraphicObjects_8idl.html", "TextGraphicObjects_8idl" ],
    [ "TextGridMode.idl", "TextGridMode_8idl.html", "TextGridMode_8idl" ],
    [ "TextLayoutCursor.idl", "TextLayoutCursor_8idl.html", "TextLayoutCursor_8idl" ],
    [ "TextMarkupDescriptor.idl", "TextMarkupDescriptor_8idl.html", "TextMarkupDescriptor_8idl" ],
    [ "TextMarkupType.idl", "TextMarkupType_8idl.html", "TextMarkupType_8idl" ],
    [ "TextPageStyle.idl", "TextPageStyle_8idl.html", "TextPageStyle_8idl" ],
    [ "TextPortion.idl", "TextPortion_8idl.html", "TextPortion_8idl" ],
    [ "TextPortionEnumeration.idl", "TextPortionEnumeration_8idl.html", "TextPortionEnumeration_8idl" ],
    [ "TextPosition.idl", "TextPosition_8idl.html", "TextPosition_8idl" ],
    [ "TextRange.idl", "TextRange_8idl.html", "TextRange_8idl" ],
    [ "TextRangeContentProperties.idl", "TextRangeContentProperties_8idl.html", "TextRangeContentProperties_8idl" ],
    [ "TextRanges.idl", "TextRanges_8idl.html", "TextRanges_8idl" ],
    [ "TextRangeSelection.idl", "TextRangeSelection_8idl.html", "TextRangeSelection_8idl" ],
    [ "TextSection.idl", "TextSection_8idl.html", "TextSection_8idl" ],
    [ "TextSections.idl", "TextSections_8idl.html", "TextSections_8idl" ],
    [ "TextSortable.idl", "TextSortable_8idl.html", "TextSortable_8idl" ],
    [ "TextSortDescriptor.idl", "TextSortDescriptor_8idl.html", "TextSortDescriptor_8idl" ],
    [ "TextSortDescriptor2.idl", "TextSortDescriptor2_8idl.html", "TextSortDescriptor2_8idl" ],
    [ "TextTable.idl", "TextTable_8idl.html", "TextTable_8idl" ],
    [ "TextTableCursor.idl", "TextTableCursor_8idl.html", "TextTableCursor_8idl" ],
    [ "TextTableRow.idl", "TextTableRow_8idl.html", "TextTableRow_8idl" ],
    [ "TextTables.idl", "TextTables_8idl.html", "TextTables_8idl" ],
    [ "TextViewCursor.idl", "TextViewCursor_8idl.html", "TextViewCursor_8idl" ],
    [ "TimeDisplayFormat.idl", "TimeDisplayFormat_8idl.html", "TimeDisplayFormat_8idl" ],
    [ "UserDataPart.idl", "UserDataPart_8idl.html", "UserDataPart_8idl" ],
    [ "UserDefinedIndex.idl", "UserDefinedIndex_8idl.html", "UserDefinedIndex_8idl" ],
    [ "UserFieldFormat.idl", "UserFieldFormat_8idl.html", "UserFieldFormat_8idl" ],
    [ "UserIndex.idl", "UserIndex_8idl.html", "UserIndex_8idl" ],
    [ "UserIndexMark.idl", "UserIndexMark_8idl.html", "UserIndexMark_8idl" ],
    [ "VertOrientation.idl", "VertOrientation_8idl.html", "VertOrientation_8idl" ],
    [ "VertOrientationFormat.idl", "VertOrientationFormat_8idl.html", "VertOrientationFormat_8idl" ],
    [ "ViewSettings.idl", "text_2ViewSettings_8idl.html", "text_2ViewSettings_8idl" ],
    [ "WebDocument.idl", "WebDocument_8idl.html", "WebDocument_8idl" ],
    [ "WrapInfluenceOnPosition.idl", "WrapInfluenceOnPosition_8idl.html", "WrapInfluenceOnPosition_8idl" ],
    [ "WrapTextMode.idl", "WrapTextMode_8idl.html", "WrapTextMode_8idl" ],
    [ "WritingMode.idl", "WritingMode_8idl.html", "WritingMode_8idl" ],
    [ "WritingMode2.idl", "WritingMode2_8idl.html", "WritingMode2_8idl" ],
    [ "XAutoTextContainer.idl", "XAutoTextContainer_8idl.html", "XAutoTextContainer_8idl" ],
    [ "XAutoTextContainer2.idl", "XAutoTextContainer2_8idl.html", "XAutoTextContainer2_8idl" ],
    [ "XAutoTextEntry.idl", "XAutoTextEntry_8idl.html", "XAutoTextEntry_8idl" ],
    [ "XAutoTextGroup.idl", "XAutoTextGroup_8idl.html", "XAutoTextGroup_8idl" ],
    [ "XBookmarkInsertTool.idl", "XBookmarkInsertTool_8idl.html", "XBookmarkInsertTool_8idl" ],
    [ "XBookmarksSupplier.idl", "text_2XBookmarksSupplier_8idl.html", "text_2XBookmarksSupplier_8idl" ],
    [ "XChapterNumberingSupplier.idl", "XChapterNumberingSupplier_8idl.html", "XChapterNumberingSupplier_8idl" ],
    [ "XContentControlsSupplier.idl", "XContentControlsSupplier_8idl.html", "XContentControlsSupplier_8idl" ],
    [ "XDefaultNumberingProvider.idl", "XDefaultNumberingProvider_8idl.html", "XDefaultNumberingProvider_8idl" ],
    [ "XDependentTextField.idl", "XDependentTextField_8idl.html", "XDependentTextField_8idl" ],
    [ "XDocumentIndex.idl", "XDocumentIndex_8idl.html", "XDocumentIndex_8idl" ],
    [ "XDocumentIndexesSupplier.idl", "XDocumentIndexesSupplier_8idl.html", "XDocumentIndexesSupplier_8idl" ],
    [ "XDocumentIndexMark.idl", "XDocumentIndexMark_8idl.html", "XDocumentIndexMark_8idl" ],
    [ "XEndnotesSettingsSupplier.idl", "XEndnotesSettingsSupplier_8idl.html", "XEndnotesSettingsSupplier_8idl" ],
    [ "XEndnotesSupplier.idl", "XEndnotesSupplier_8idl.html", "XEndnotesSupplier_8idl" ],
    [ "XFlatParagraph.idl", "XFlatParagraph_8idl.html", "XFlatParagraph_8idl" ],
    [ "XFlatParagraphIterator.idl", "XFlatParagraphIterator_8idl.html", "XFlatParagraphIterator_8idl" ],
    [ "XFlatParagraphIteratorProvider.idl", "XFlatParagraphIteratorProvider_8idl.html", "XFlatParagraphIteratorProvider_8idl" ],
    [ "XFootnote.idl", "XFootnote_8idl.html", "XFootnote_8idl" ],
    [ "XFootnotesSettingsSupplier.idl", "XFootnotesSettingsSupplier_8idl.html", "XFootnotesSettingsSupplier_8idl" ],
    [ "XFootnotesSupplier.idl", "XFootnotesSupplier_8idl.html", "XFootnotesSupplier_8idl" ],
    [ "XFormField.idl", "XFormField_8idl.html", "XFormField_8idl" ],
    [ "XLineNumberingProperties.idl", "XLineNumberingProperties_8idl.html", "XLineNumberingProperties_8idl" ],
    [ "XMailMergeBroadcaster.idl", "XMailMergeBroadcaster_8idl.html", "XMailMergeBroadcaster_8idl" ],
    [ "XMailMergeListener.idl", "XMailMergeListener_8idl.html", "XMailMergeListener_8idl" ],
    [ "XMarkingAccess.idl", "XMarkingAccess_8idl.html", "XMarkingAccess_8idl" ],
    [ "XMultiTextMarkup.idl", "XMultiTextMarkup_8idl.html", "XMultiTextMarkup_8idl" ],
    [ "XNumberingFormatter.idl", "XNumberingFormatter_8idl.html", "XNumberingFormatter_8idl" ],
    [ "XNumberingRulesSupplier.idl", "XNumberingRulesSupplier_8idl.html", "XNumberingRulesSupplier_8idl" ],
    [ "XNumberingTypeInfo.idl", "XNumberingTypeInfo_8idl.html", "XNumberingTypeInfo_8idl" ],
    [ "XPageCursor.idl", "XPageCursor_8idl.html", "XPageCursor_8idl" ],
    [ "XPagePrintable.idl", "XPagePrintable_8idl.html", "XPagePrintable_8idl" ],
    [ "XParagraphAppend.idl", "XParagraphAppend_8idl.html", "XParagraphAppend_8idl" ],
    [ "XParagraphCursor.idl", "XParagraphCursor_8idl.html", "XParagraphCursor_8idl" ],
    [ "XPasteBroadcaster.idl", "XPasteBroadcaster_8idl.html", "XPasteBroadcaster_8idl" ],
    [ "XPasteListener.idl", "XPasteListener_8idl.html", "XPasteListener_8idl" ],
    [ "XRedline.idl", "XRedline_8idl.html", "XRedline_8idl" ],
    [ "XReferenceMarksSupplier.idl", "XReferenceMarksSupplier_8idl.html", "XReferenceMarksSupplier_8idl" ],
    [ "XRelativeTextContentInsert.idl", "XRelativeTextContentInsert_8idl.html", "XRelativeTextContentInsert_8idl" ],
    [ "XRelativeTextContentRemove.idl", "XRelativeTextContentRemove_8idl.html", "XRelativeTextContentRemove_8idl" ],
    [ "XRubySelection.idl", "XRubySelection_8idl.html", "XRubySelection_8idl" ],
    [ "XSentenceCursor.idl", "XSentenceCursor_8idl.html", "XSentenceCursor_8idl" ],
    [ "XSimpleText.idl", "XSimpleText_8idl.html", "XSimpleText_8idl" ],
    [ "XText.idl", "text_2XText_8idl.html", "text_2XText_8idl" ],
    [ "XTextAppend.idl", "XTextAppend_8idl.html", "XTextAppend_8idl" ],
    [ "XTextAppendAndConvert.idl", "XTextAppendAndConvert_8idl.html", "XTextAppendAndConvert_8idl" ],
    [ "XTextColumns.idl", "XTextColumns_8idl.html", "XTextColumns_8idl" ],
    [ "XTextContent.idl", "XTextContent_8idl.html", "XTextContent_8idl" ],
    [ "XTextContentAppend.idl", "XTextContentAppend_8idl.html", "XTextContentAppend_8idl" ],
    [ "XTextConvert.idl", "XTextConvert_8idl.html", "XTextConvert_8idl" ],
    [ "XTextCopy.idl", "XTextCopy_8idl.html", "XTextCopy_8idl" ],
    [ "XTextCursor.idl", "XTextCursor_8idl.html", "XTextCursor_8idl" ],
    [ "XTextDocument.idl", "XTextDocument_8idl.html", "XTextDocument_8idl" ],
    [ "XTextEmbeddedObjectsSupplier.idl", "XTextEmbeddedObjectsSupplier_8idl.html", "XTextEmbeddedObjectsSupplier_8idl" ],
    [ "XTextField.idl", "XTextField_8idl.html", "XTextField_8idl" ],
    [ "XTextFieldsSupplier.idl", "XTextFieldsSupplier_8idl.html", "XTextFieldsSupplier_8idl" ],
    [ "XTextFrame.idl", "XTextFrame_8idl.html", "XTextFrame_8idl" ],
    [ "XTextFramesSupplier.idl", "XTextFramesSupplier_8idl.html", "XTextFramesSupplier_8idl" ],
    [ "XTextGraphicObjectsSupplier.idl", "XTextGraphicObjectsSupplier_8idl.html", "XTextGraphicObjectsSupplier_8idl" ],
    [ "XTextMarkup.idl", "XTextMarkup_8idl.html", "XTextMarkup_8idl" ],
    [ "XTextPortionAppend.idl", "XTextPortionAppend_8idl.html", "XTextPortionAppend_8idl" ],
    [ "XTextRange.idl", "XTextRange_8idl.html", "XTextRange_8idl" ],
    [ "XTextRangeCompare.idl", "XTextRangeCompare_8idl.html", "XTextRangeCompare_8idl" ],
    [ "XTextRangeMover.idl", "XTextRangeMover_8idl.html", "XTextRangeMover_8idl" ],
    [ "XTextSection.idl", "XTextSection_8idl.html", "XTextSection_8idl" ],
    [ "XTextSectionsSupplier.idl", "XTextSectionsSupplier_8idl.html", "XTextSectionsSupplier_8idl" ],
    [ "XTextShapesSupplier.idl", "XTextShapesSupplier_8idl.html", "XTextShapesSupplier_8idl" ],
    [ "XTextTable.idl", "XTextTable_8idl.html", "XTextTable_8idl" ],
    [ "XTextTableCursor.idl", "XTextTableCursor_8idl.html", "XTextTableCursor_8idl" ],
    [ "XTextTablesSupplier.idl", "XTextTablesSupplier_8idl.html", "XTextTablesSupplier_8idl" ],
    [ "XTextViewCursor.idl", "XTextViewCursor_8idl.html", "XTextViewCursor_8idl" ],
    [ "XTextViewCursorSupplier.idl", "XTextViewCursorSupplier_8idl.html", "XTextViewCursorSupplier_8idl" ],
    [ "XTextViewTextRangeSupplier.idl", "XTextViewTextRangeSupplier_8idl.html", "XTextViewTextRangeSupplier_8idl" ],
    [ "XWordCursor.idl", "XWordCursor_8idl.html", "XWordCursor_8idl" ]
];